==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebPaneCloseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebPaneCloseEventArgsDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneCloseEventArgsDescriptionMetadata.b(a);
            a.u("WebPaneCloseEventArgs", () => new WebPaneCloseEventArgsDescription());
            a.t("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebPaneCloseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPaneCloseEventArgsDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneCloseEventArgsDescriptionMetadata.b(a);
            a.aa("WebPaneCloseEventArgs", () => new WebPaneCloseEventArgsDescription());
            a.z("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
})();
